==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/UpstreamAuthSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs.builder
import com.pulumi.azurenative.webpubsub.kotlin.enums.UpstreamAuthType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Upstream auth settings. If not set, no auth is used for upstream messages.
 * @property managedIdentity Managed identity settings for upstream.
 * @property type Upstream auth type enum.
 */
public data class UpstreamAuthSettingsArgs(
    public val managedIdentity: Output<ManagedIdentitySettingsArgs>? = null,
    public val type: Output<Either<String, UpstreamAuthType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs =
        com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs.builder()
            .managedIdentity(managedIdentity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [UpstreamAuthSettingsArgs].
 */
@PulumiTagMarker
public class UpstreamAuthSettingsArgsBuilder internal constructor() {
    private var managedIdentity: Output<ManagedIdentitySettingsArgs>? = null

    private var type: Output<Either<String, UpstreamAuthType>>? = null

    /**
     * @param value Managed identity settings for upstream.
     */
    @JvmName("ywibtjjfmovpgyrv")
    public suspend fun managedIdentity(`value`: Output<ManagedIdentitySettingsArgs>) {
        this.managedIdentity = value
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("lffsbmobixxpreqq")
    public suspend fun type(`value`: Output<Either<String, UpstreamAuthType>>) {
        this.type = value
    }

    /**
     * @param value Managed identity settings for upstream.
     */
    @JvmName("fnbsdnxegjjgvsge")
    public suspend fun managedIdentity(`value`: ManagedIdentitySettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedIdentity = mapped
    }

    /**
     * @param argument Managed identity settings for upstream.
     */
    @JvmName("hqisdelchoumgdcy")
    public suspend
    fun managedIdentity(argument: suspend ManagedIdentitySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedIdentitySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managedIdentity = mapped
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("cmjrnahfnnqpfece")
    public suspend fun type(`value`: Either<String, UpstreamAuthType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("fcfvnnfahivqlguh")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, UpstreamAuthType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("ucaeixpwibrsetyr")
    public fun type(`value`: UpstreamAuthType) {
        val toBeMapped = Either.ofRight<String, UpstreamAuthType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): UpstreamAuthSettingsArgs = UpstreamAuthSettingsArgs(
        managedIdentity = managedIdentity,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/UpstreamAuthSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs.builder
import com.pulumi.azurenative.webpubsub.kotlin.enums.UpstreamAuthType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Upstream auth settings. If not set, no auth is used for upstream messages.
 * @property managedIdentity Managed identity settings for upstream.
 * @property type Upstream auth type enum.
 */
public data class UpstreamAuthSettingsArgs(
    public val managedIdentity: Output<ManagedIdentitySettingsArgs>? = null,
    public val type: Output<Either<String, UpstreamAuthType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs =
        com.pulumi.azurenative.webpubsub.inputs.UpstreamAuthSettingsArgs.builder()
            .managedIdentity(managedIdentity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [UpstreamAuthSettingsArgs].
 */
@PulumiTagMarker
public class UpstreamAuthSettingsArgsBuilder internal constructor() {
    private var managedIdentity: Output<ManagedIdentitySettingsArgs>? = null

    private var type: Output<Either<String, UpstreamAuthType>>? = null

    /**
     * @param value Managed identity settings for upstream.
     */
    @JvmName("iilxvrxanduyydjv")
    public suspend fun managedIdentity(`value`: Output<ManagedIdentitySettingsArgs>) {
        this.managedIdentity = value
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("vyfqldddvunujqmv")
    public suspend fun type(`value`: Output<Either<String, UpstreamAuthType>>) {
        this.type = value
    }

    /**
     * @param value Managed identity settings for upstream.
     */
    @JvmName("mtrlsplvmkqxgldf")
    public suspend fun managedIdentity(`value`: ManagedIdentitySettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedIdentity = mapped
    }

    /**
     * @param argument Managed identity settings for upstream.
     */
    @JvmName("lmncbjhewbpemtvs")
    public suspend
    fun managedIdentity(argument: suspend ManagedIdentitySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedIdentitySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managedIdentity = mapped
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("dlokwmwcggtxvona")
    public suspend fun type(`value`: Either<String, UpstreamAuthType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("kkwvkkuabitftpxs")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, UpstreamAuthType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Upstream auth type enum.
     */
    @JvmName("evfcdfraasgtsiht")
    public fun type(`value`: UpstreamAuthType) {
        val toBeMapped = Either.ofRight<String, UpstreamAuthType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): UpstreamAuthSettingsArgs = UpstreamAuthSettingsArgs(
        managedIdentity = managedIdentity,
        type = type,
    )
}
